# !/bin/ksh
#############################################################################
# Licensed Materials - Property of IBM
# 5724-D33
# IBM Tivoli License Manager
#
# (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################

CATALOG_111=IBMSoftwareCatalog.dat
TRANSFORMER_XSL=catalogConverter.xsl
XALAN=../installedApp.ear/slm_admin.war/WEB-INF/lib/xalan.jar

MAX_PARMS=1
NUM_PARMS=${#}

# The number of parameters cannot be greater than MAX_PARMS
if [ ${NUM_PARMS} -gt ${MAX_PARMS} ]
then
    echo "Error: too many parameters"
    echo "Usage: catalogConverter <catalog file>"
    exit 1
fi

if [[ -z $1 ]]
then
   echo "Error: missing parameter"
   echo "Usage: catalogConverter <catalog file>"
   exit 1
fi

CATALOG_21=$1
CATALOG_21_TMP=$CATALOG_21.tmp

if [ ! -e $CATALOG_21 ]
then
   echo Error: input catalog not found: $CATALOG_21
   exit 1
fi

if [ ! -e $TRANSFORMER_XSL ]
then
   echo Error: transformation stylesheet not found: $TRANSFORMER_XSL
   exit 1
fi

# test the write permissions on output file
touch $CATALOG_21_TMP
if [ $? != 0 ]
then
  echo
  echo Cannot write to output file, permissions missing
  echo Cannot write to output file, permissions missing >> $TLM_LOG_FILE
  echo
  exit 1
fi

echo "Input catalog (TLM 2.1): $CATALOG_21"
echo "Output catalog (TLM 1.1.1): $CATALOG_111"
echo "Running (it may take a few minutes)..."

CLASSPATH=$CLASSPATH:$XALAN
java org.apache.xalan.xslt.Process -IN ${CATALOG_21} -XSL ${TRANSFORMER_XSL} -OUT ${CATALOG_21_TMP} -param PREPROCESS true
java org.apache.xalan.xslt.Process -IN ${CATALOG_21_TMP} -XSL ${TRANSFORMER_XSL} -OUT ${CATALOG_111} -param PREPROCESS false
RC=$?

if [ -e ${CATALOG_21_TMP} ]
then
    rm ${CATALOG_21_TMP}
fi

if [ $RC -gt 0 ]
then
   echo "Error: transformation failed"
   exit 1
else
   echo "Catalog conversion successful."
   exit 0
fi
