-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-D33
-- * IBM Tivoli License Manager
-- *
-- * (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
-- *
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************


-------------------------------------------------------------------------------
-- Create foreign keys
-------------------------------------------------------------------------------

alter table ADM.ADMIN_CUST_REL add constraint ACR_ADM_FK
    foreign key(ADMINISTRATOR_ID) references ADM.ADMINISTRATOR on delete cascade;

alter table ADM.ADMIN_CUST_REL add constraint ACR_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.ADMIN_CUST_REL add constraint ACR_PRO_FK
    foreign key(PROFILE_ID) references ADM.PROFILE on delete cascade;

alter table ADM.AGENT add constraint AGT_SER_FK
    foreign key(SERVER_ID) references ADM.SERVER on delete cascade;

alter table ADM.AGENT add constraint AGT_NOD_FK
    foreign key(NODE_ID) references ADM.NODE on delete cascade;

alter table ADM.AGENT add constraint AGT_DIV_FK
    foreign key(DIVISION_ID) references ADM.DIVISION on delete cascade;

alter table ADM.AGENT add constraint AGT_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.AGENT_EVENT add constraint AET_AGT_FK
    foreign key(AGENT_ID) references ADM.AGENT on delete cascade;

alter table ADM.AGENT_INV add constraint AIV_CMP_FK
    foreign key(COMPONENT_ID) references ADM.COMPONENT on delete cascade;

alter table ADM.AGENT_INV_LIC add constraint AIV_AIL_FK
    foreign key(AGENT_INV_ID) references ADM.AGENT_INV on delete cascade;

alter table ADM.CONTRACT add constraint CON_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.CUST_OPT_FIELD add constraint COF_OPF_FK
    foreign key(OPT_FIELD_ID) references ADM.OPT_FIELD_DEF on delete cascade;

alter table ADM.CUST_OPT_FIELD add constraint COF_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.CUSTOMER add constraint CUS_COU_FK
    foreign key(COUNTRY_CODE) references ADM.COUNTRY on delete set null;

alter table ADM.DIVISION add constraint DIV_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete restrict;

alter table ADM.ENDUSER add constraint END_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.ENTITLEMENT add constraint ENT_CMP_FK
    foreign key(COMPONENT_ID) references ADM.COMPONENT on delete cascade;

alter table ADM.ENTITLEMENT add constraint ENT_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.LIC_TARGET_REL add constraint LTR_LIC_FK
    foreign key(LICENSE_ID) references ADM.LICENSE on delete cascade;

alter table ADM.LIC_USER_REL add constraint LUR_LIC_FK
    foreign key(LICENSE_ID) references ADM.LICENSE on delete cascade;

alter table ADM.LIC_USER_REL add constraint LUR_END_FK
    foreign key(ENDUSER_ID) references ADM.ENDUSER on delete cascade;

alter table ADM.LICENSE add constraint LIC_PLI_FK
    foreign key(PLICENSE_ID) references ADM.PLICENSE on delete cascade;

alter table ADM.LICENSE_DISTRIBUTION add constraint LID_SER_FK
    foreign key(SERVER_ID) references ADM.SERVER on delete cascade;

alter table ADM.NODE add constraint NOD_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.OPT_FIELD add constraint OPF_OFD_FK
    foreign key(OPT_FIELD_ID) references ADM.OPT_FIELD_DEF on delete cascade;

alter table ADM.PLIC_COMP_REL add constraint PCR_PLI_FK
    foreign key(PLICENSE_ID) references ADM.PLICENSE on delete cascade;

alter table ADM.PLIC_COMP_REL add constraint PCR_CMP_FK
    foreign key(COMPONENT_ID) references ADM.COMPONENT on delete cascade;

alter table ADM.PLICENSE add constraint PLI_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete cascade;

alter table ADM.PROFILE_ACTION add constraint PRA_PRO_FK
    foreign key(PROFILE_ID) references ADM.PROFILE on delete cascade;

alter table ADM.SERVER add constraint SER_SER_FK
    foreign key(BACKUP_SERVER_ID) references ADM.SERVER on delete set null;

alter table ADM.SERVER add constraint SER_CUS_FK
    foreign key(CUSTOMER_ID) references ADM.CUSTOMER on delete restrict;

alter table ADM.USAGE_COMP_USER add constraint USU_USC_FK
    foreign key(USAGE_COMP_ID) references ADM.USAGE_COMP on delete cascade;

alter table ADM.USAGE_LIC add constraint USL_USC_FK
    foreign key(USAGE_COMP_ID) references ADM.USAGE_COMP on delete cascade;


-------------------------------------------------------------------------------
-- Create check constraints
-------------------------------------------------------------------------------

alter table ADM.AGENT add constraint AGENT_CK1
    check  ( OS_NAME in  ( 'Unix', 'Windows', 'OS/400') );

alter table ADM.AGENT add constraint AGENT_CK2
    check  ( SECURITY_LEVEL in  ( 1, 2, 3, 4) );

alter table ADM.AGENT add constraint AGENT_CK3
    check  ( ACTIVE in  ( 0, 1, 2) );

alter table ADM.CUSTOMER add constraint CUSTOMER_CK1
    check  ( SECURITY_LEVEL in  ( 1, 2, 3, 4) );

alter table ADM.DIVISION add constraint DIVISION_CK1
    check  ( INV_RATE_TYPE in  ( 0, 1, 2, 3) );

alter table ADM.DIVISION add constraint DIVISION_CK2
    check  ( SECURITY_LEVEL in  ( 0, 1, 2, 3, 4) );

alter table ADM.LICENSE add constraint LICENSE_CK1
    check  ( TARGET_TYPE in  ( 1, 2, 3, 4) );

alter table ADM.LICENSE add constraint LICENSE_CK2
    check  ( ALL_TARGETS in  ( 0, 1) );

alter table ADM.LICENSE add constraint LICENSE_CK3
    check  ( ALL_USERS in  ( 0, 1) );

alter table ADM.NODE add constraint NODE_CK1
    check  ( PLATFORM in  ( 'i686', 'x86', 'i386', 'ppc', 'ppc64', 'PowerPC', 'PowerPC32', 'PowerPC64', 's390', 'sparc', 'sparcv9', 'PA-RISC') );

alter table ADM.PLICENSE add constraint PLICENSE_CK1
    check  ( LICENSE_TYPE in  ( 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 101) );

alter table ADM.PLICENSE add constraint PLICENSE_CK2
    check  ( MULTI_INSTANCE in  ( 0, 1, 2, 3) );

alter table ADM.PLICENSE add constraint PLICENSE_CK3
    check  ( CAPACITY_TYPE in  ( 0, 1, 2, 4) );

alter table ADM.SERVER add constraint SERVER_CK1
    check  ( OUTAGE_STATUS in  ( 0, 1, 2, 3) );


-------------------------------------------------------------------------------
-- Create timestamp triggers
-------------------------------------------------------------------------------

create trigger ADM.ADMIN_CUST_REL_TR1
    no cascade before insert on ADM.ADMIN_CUST_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.ADMIN_CUST_REL_TR2
    no cascade before update on ADM.ADMIN_CUST_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.ADMINISTRATOR_TR1
    no cascade before insert on ADM.ADMINISTRATOR
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.ADMINISTRATOR_TR2
    no cascade before update on ADM.ADMINISTRATOR
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.AGENT_TR1
    no cascade before insert on ADM.AGENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.AGENT_TR2
    no cascade before update on ADM.AGENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.CONTRACT_TR1
    no cascade before insert on ADM.CONTRACT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.CONTRACT_TR2
    no cascade before update on ADM.CONTRACT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.CUSTOMER_TR1
    no cascade before insert on ADM.CUSTOMER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.CUSTOMER_TR2
    no cascade before update on ADM.CUSTOMER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.DIVISION_TR1
    no cascade before insert on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.DIVISION_TR2
    no cascade before update on ADM.DIVISION
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.ENDUSER_TR1
    no cascade before insert on ADM.ENDUSER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.ENDUSER_TR2
    no cascade before update on ADM.ENDUSER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.ENTITLEMENT_TR1
    no cascade before insert on ADM.ENTITLEMENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.ENTITLEMENT_TR2
    no cascade before update on ADM.ENTITLEMENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.LIC_TARGET_REL_TR1
    no cascade before insert on ADM.LIC_TARGET_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.LIC_TARGET_REL_TR2
    no cascade before update on ADM.LIC_TARGET_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.LIC_USER_REL_TR1
    no cascade before insert on ADM.LIC_USER_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.LIC_USER_REL_TR2
    no cascade before update on ADM.LIC_USER_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.LICENSE_TR1
    no cascade before insert on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.LICENSE_TR2
    no cascade before update on ADM.LICENSE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.LICENSE_DISTRI_TR1
    no cascade before insert on ADM.LICENSE_DISTRIBUTION
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.LICENSE_DISTRI_TR2
    no cascade before update on ADM.LICENSE_DISTRIBUTION
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.NODE_TR1
    no cascade before insert on ADM.NODE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.NODE_TR2
    no cascade before update on ADM.NODE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.PLICENSE_TR1
    no cascade before insert on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.PLICENSE_TR2
    no cascade before update on ADM.PLICENSE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger ADM.SERVER_TR1
    no cascade before insert on ADM.SERVER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger ADM.SERVER_TR2
    no cascade before update on ADM.SERVER
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------
