-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-D33
-- * IBM Tivoli License Manager
-- *
-- * (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
-- *              
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************


-------------------------------------------------------------------------------
-- Create views
-------------------------------------------------------------------------------

create view ADM.ADMINISTRATOR_V
(
    ADMINISTRATOR_ID,
    ADMINISTRATOR_NAME,
    PROFILE_ID,
    CUSTOMER_NAME
)
as
    select
        A.ID,
        substr(A.LOGON_NAME, 1, 20),
        R.PROFILE_ID,
        substr(C.NAME, 1, 20)
    from
        ADM.ADMINISTRATOR A,
        ADM.ADMIN_CUST_REL R,
        ADM.CUSTOMER C
    where
        A.ID = R.ADMINISTRATOR_ID and
        R.CUSTOMER_ID = C.ID;

grant select on ADM.ADMINISTRATOR_V to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.DIVISION_V
(
    ID,
    NAME,
    CUSTOMER_NAME
)
as
    select
        D.ID,
        D.NAME,
        C.NAME
    from
        ADM.DIVISION D,
        ADM.CUSTOMER C
    where
        D.CUSTOMER_ID = C.ID;

grant select on ADM.DIVISION_V to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.USAGE_V
(
    ID,
    AGENT,
    COMPONENT,
    START_TIME,
    END_TIME,
    LIC_REF_CODE,
    LIC_QUANTITY,
    LIC_START_TIME,
    LIC_END_TIME
)
as
    select
        UC.ID,
        substr(A.HOSTNAME, 1, 30),
        substr(C.NAME CONCAT ' ' concat C.VERSION, 1, 50),
        UC.START_TIME,
        UC.END_TIME,
        L.REF_CODE,
        UL.QUANTITY,
        UL.START_TIME,
        UL.END_TIME
    from
        ADM.USAGE_COMP UC left outer join ADM.USAGE_LIC UL on UC.ID = UL.USAGE_COMP_ID
        left outer join ADM.LICENSE L on UL.LICENSE_ID = L.ID,
        ADM.COMPONENT C,
        ADM.AGENT A
    where
        UC.COMPONENT_ID = C.ID and
        UC.AGENT_ID = A.ID;

grant select on ADM.USAGE_V to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.AGENT_INV_V
(
    ID,
    AGENT,
    COMPONENT,
    START_TIME,
    END_TIME,
    LIC_REF_CODE,
    LIC_QUANTITY,
    LIC_START_TIME,
    LIC_END_TIME
)
as
    select
        I.ID,
        substr(A.HOSTNAME, 1, 30),
        substr(C.NAME CONCAT ' ' concat C.VERSION, 1, 50),
        I.START_TIME,
        I.END_TIME,
        L.REF_CODE,
        IL.QUANTITY,
        IL.START_TIME,
        IL.END_TIME
    from
        ADM.AGENT_INV I left outer join ADM.AGENT_INV_LIC IL on I.ID = IL.AGENT_INV_ID
        left outer join ADM.LICENSE L on IL.LICENSE_ID = L.ID,
        ADM.COMPONENT C,
        ADM.AGENT A
    where
        I.COMPONENT_ID = C.ID and
        I.AGENT_ID = A.ID;

grant select on ADM.AGENT_INV_V to user TLMSRV;


-------------------------------------------------------------------------------
-- Tivoli Data Warehouse (TDW) views
-------------------------------------------------------------------------------

create view ADM.TDW_AGENT
(
    ID,
    OS_VERSION,
    VERSION,
    GROUP_ID,
    ORGANIZATION_ID,
    START_TIME,
    END_TIME
)
as
    select
        A.ID,
        A.OS_VERSION,
        A.VERSION,
        A.DIVISION_ID,
        A.CUSTOMER_ID,
        A.START_TIME,
        A.END_TIME
    from
        ADM.AGENT_H A;

grant select on ADM.TDW_AGENT to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_INSTALL
(
    AGENT_ID,
    PRODUCT_ID,
    START_TIME,
    END_TIME
)
as
    select
        I.AGENT_ID,
        I.COMPONENT_ID,
        I.START_TIME,
        I.END_TIME
    from
        ADM.AGENT_INV I;

grant select on ADM.TDW_INSTALL to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_ORGANIZATION
(
    ID,
    NAME
)
as
    select
        C.ID,
        C.NAME
    from
        ADM.CUSTOMER C;

grant select on ADM.TDW_ORGANIZATION to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_GROUP
(
    ID,
    NAME,
    ORGANIZATION_ID,
    START_TIME,
    END_TIME
)
as
    select
        D.ID,
        D.NAME,
        D.CUSTOMER_ID,
        D.START_TIME,
        D.END_TIME
    from
        ADM.DIVISION_H D;

grant select on ADM.TDW_GROUP to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_PRODUCT
(
    ID,
    NAME,
    VERSION,
    OS_NAME,
    AGGR_LEVEL,
    MANUFACTURER_ID
)
as
    select
        P.ID,
        P.NAME,
        P.VERSION,
        P.OS_NAME,
        P.TREE_LEVEL,
        P.VENDOR_ID
    from
        ADM.COMPONENT P;

grant select on ADM.TDW_PRODUCT to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_MANUFACTURER
(
    ID,
    NAME
)
as
    select
        V.ID,
        V.NAME
    from
        ADM.VENDOR V;

grant select on ADM.TDW_MANUFACTURER to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_PLIC_PROD_REL
(
    PLICENSE_ID,
    PRODUCT_ID,
    START_TIME,
    END_TIME
)
as
    select
        P.PLICENSE_ID,
        P.COMPONENT_ID,
        P.START_TIME,
        P.END_TIME
    from
        ADM.PLIC_COMP_HREL P;

grant select on ADM.TDW_PLIC_PROD_REL to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_PLICENSE
(
    PLICENSE_ID,
    REF_CODE,
    CAPACITY_TYPE,
    SOFTWARE_NAME,
    LICENSE_TYPE,
    ORGANIZATION_ID,
    START_TIME,
    END_TIME
)
as
    select
        P.ID,
        P.REF_CODE,
        P.CAPACITY_TYPE,
        P.SOFTWARE_NAME,
        P.LICENSE_TYPE,
        P.CUSTOMER_ID,
        P.START_TIME,
        P.END_TIME
    from
        ADM.PLICENSE_H P;

grant select on ADM.TDW_PLICENSE to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_LICENSE
(
    LICENSE_ID,
    REF_CODE,
    QUANTITY,
    ORGANIZATION_ID,
    PLICENSE_ID,
    START_TIME,
    END_TIME
)
as
    select
        L.ID,
        L.REF_CODE,
        L.QUANTITY,
        L.CUSTOMER_ID,
        L.PLICENSE_ID,
        L.START_TIME,
        L.END_TIME
    from
        ADM.LICENSE_H L;

grant select on ADM.TDW_LICENSE to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_USAGE_H_LIC
(
    ID,
    LICENSE_ID,
    DATE_USAGE,
    HWM,
    AWM
)
as
    select
        U.ID,
        U.LICENSE_ID,
        U.DATE_USAGE,
        U.HWM,
        U.AWM
    from
        ADM.USAGE_H_LIC U;

grant select on ADM.TDW_USAGE_H_LIC to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_USAGE_H_GRP
(
    ID,
    PRODUCT_ID,
    GROUP_ID,
    DATE_USAGE,
    HWM,
    AWM
)
as
    select
        U.ID,
        U.COMPONENT_ID,
        U.DIVISION_ID,
        U.DATE_USAGE,
        U.HWM,
        U.AWM
    from
        ADM.USAGE_H_DIV U;

grant select on ADM.TDW_USAGE_H_GRP to user TLMSRV;

-------------------------------------------------------------------------------

create view ADM.TDW_USAGE_H_ORG
(
    ID,
    PRODUCT_ID,
    ORGANIZATION_ID,
    DATE_USAGE,
    HWM,
    AWM
)
as
    select
        U.ID,
        U.COMPONENT_ID,
        U.CUSTOMER_ID,
        U.DATE_USAGE,
        U.HWM,
        U.AWM
    from
        ADM.USAGE_H_COMP U;

grant select on ADM.TDW_USAGE_H_ORG to user TLMSRV;

