#!/bin/sh
#############################################################################
# Licensed Materials - Property of IBM
# 5724-D33
# IBM Tivoli License Manager
#
# (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################


TLM_LOG_FILE=ext_id_update_111.log

# test the write permissions on log file and backup db directory
touch $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo
  echo Cannot write on log file, permissions missing
  echo Cannot write on log file, permissions missing >> $TLM_LOG_FILE
  echo
  return
fi

# clean old files - log
if test -f $TLM_LOG_FILE
then
  rm -f $TLM_LOG_FILE
fi

# check DB2 command line environment
if [[ $DB2DIR = '' ]]
then
  echo
  echo DB2 command line environment not initialized
  echo DB2 command line environment not initialized >> $TLM_LOG_FILE
  echo
  return
fi

echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
echo "Running ext_id migration" >> $TLM_LOG_FILE
date >> $TLM_LOG_FILE
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE

# check for db existence
echo Check for db existence >> $TLM_LOG_FILE
db2 +o -z $TLM_LOG_FILE connect to TLMA
if [ $? != 0 ]
then
    echo "The administration server db doesn't exist" >> $TLM_LOG_FILE
    echo "The administration server db doesn't exist"
    return
fi

# check for db access
echo Check for db access >> $TLM_LOG_FILE
db2 +o -z $TLM_LOG_FILE "select VALUE from ADM.CONTROL WHERE name='DATABASE_VERSION'"
if [ $? != 0 ]
then
    echo "Cannot access administration server db." >> $TLM_LOG_FILE
    echo "Cannot access administration server db."
    echo "Database administration permission on TLMA is needed" >> $TLM_LOG_FILE
    echo "Database administration permission on TLMA is needed"
    return
fi

# preliminary checks
echo Preliminary checks on db running >> $TLM_LOG_FILE
db2 +o -t -f checks_111_21.sql -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "Preliminary checks on to be migrated db failed." >> $TLM_LOG_FILE
  echo "Check database version is 1.1.1." >> $TLM_LOG_FILE
  echo "Cannot start update procedure. Database version is not the one expected (1.1.1)"
  db2 +o disconnect TLMA
  return
fi
echo "Preliminary checks completed successfully" >> $TLM_LOG_FILE

# Performing Ext_id update
echo "Ext_id column update running..."
db2 +o -z $TLM_LOG_FILE connect to TLMA
db2 -f ext_id_update_111.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "Ext_id update procedure failed - see log ($TLM_LOG_FILE) for details"
  db2 +o disconnect TLMA
  return
fi

#disconnect
db2 +o disconnect TLMA

echo "Administration database has been successfully updated"
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
echo "Administration database has been successfully updated" >> $TLM_LOG_FILE
date >> $TLM_LOG_FILE
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
