#!/bin/sh
#############################################################################
# Licensed Materials - Property of IBM
# 5724-D33
# IBM Tivoli License Manager
#
# (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#############################################################################


TLM_LOG_FILE=migration_111_21.log
JAVA_BIN=java
JAVA_CLASSPATH=$HOME/sqllib/java/db2java.zip:$HOME/sqllib/java/db2jcc.jar:.
TLMA_BACKUP_FILE=TLMA.0

# test the write permissions on log file and backup db directory
touch $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo
  echo Cannot write on log file, permissions missing
  echo Cannot write on log file, permissions missing >> $TLM_LOG_FILE
  echo
  return
fi

# clean old files - log and backup
if test -f $TLMA_BACKUP_FILE*
then
  rm -f $TLMA_BACKUP_FILE*
fi
if test -f $TLM_LOG_FILE
then
  rm -f $TLM_LOG_FILE
fi

# check DB2 command line environment
if [[ $DB2DIR = '' ]]
then
  echo
  echo DB2 command line environment not initialized
  echo DB2 command line environment not initialized >> $TLM_LOG_FILE
  echo
  return
fi

echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
echo "Running migration 111 21" >> $TLM_LOG_FILE
date >> $TLM_LOG_FILE
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE

# check for db existence
echo Check for db existence >> $TLM_LOG_FILE
db2 +o -z $TLM_LOG_FILE connect to TLMA
if [ $? != 0 ]
then
    echo "The administration server db doesn't exist" >> $TLM_LOG_FILE
    echo "The administration server db doesn't exist"
    return
fi

# check for db access
echo Check for db access >> $TLM_LOG_FILE
db2 +o -z $TLM_LOG_FILE "select VALUE from ADM.CONTROL WHERE name='DATABASE_VERSION'"
if [ $? != 0 ]
then
    echo "Cannot access administration server db." >> $TLM_LOG_FILE
    echo "Cannot access administration server db."
    echo "Database administration permission on TLMA is needed" >> $TLM_LOG_FILE
    echo "Database administration permission on TLMA is needed"
    return
fi

# preliminary checks
echo Preliminary checks on db running >> $TLM_LOG_FILE
db2 +o -t -f checks_111_21.sql -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "Preliminary checks on to be migrated db failed." >> $TLM_LOG_FILE
  echo "Check database version is 1.1.1." >> $TLM_LOG_FILE
  echo "Cannot start migration procedure. Database version is not the one expected (1.1.1)"
  db2 +o disconnect TLMA
  return
fi
echo "Preliminary checks completed successfully" >> $TLM_LOG_FILE

# db backup
echo Attempting database backup >> $TLM_LOG_FILE
echo Attempting database backup
db2 +o -t  -z $TLM_LOG_FILE backup db TLMA
if [ $? != 0 ]
then
  echo "Database backup failed." >> $TLM_LOG_FILE
  echo "Possible causes could be:" >> $TLM_LOG_FILE
  echo "buffer size not large enough;" >> $TLM_LOG_FILE
  echo "disk space is over;" >> $TLM_LOG_FILE
  echo "database is still in use (server not stopped? another user connected?);" >> $TLM_LOG_FILE
  echo "running script without needed autorization (how are you logged on?)" >> $TLM_LOG_FILE

  echo "Database backup failed"
  echo "Possible causes could be:"
  echo "buffer size not large enough;"
  echo "disk space over;"
  echo "database still in use (server not stopped? another user connected?);"
  echo "running script without needed autorization (how are you logged on?) "

  db2 +o disconnect TLMA
  return
fi
echo "Db backup completed successfully" >> $TLM_LOG_FILE
echo "Db backup completed successfully"

# Performing 1.1.1 foreign keys, views and triggers drop
echo "Database migration running... it could take several minutes"
echo "1.1.1 foreign keys, views and triggers drop running" >> $TLM_LOG_FILE
echo "-- running..."
db2 +o -z $TLM_LOG_FILE connect to TLMA
db2 -f drop_111.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  db2 +o disconnect TLMA
  return
fi
echo "1.1.1 foreign keys, views and triggers drop completed successfully" >> $TLM_LOG_FILE


# Altering db structure - migrating data
echo "Altering db structure - migrating data" >> $TLM_LOG_FILE
echo -- running...
db2 -v -f migrate_111_21.sql +o -t -z $TLM_LOG_FILE
if [ $? -ge 2 ]
then
  echo "A failure occurred altering db structure and migrating data" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "Database structure and data migration completed successfully" >> $TLM_LOG_FILE

# Country code management and eventual warning
echo "Verifying country code for customers" >> $TLM_LOG_FILE
db2 +o -t -z $TLM_LOG_FILE update ADM.CUSTOMER set COUNTRY_CODE=null where COUNTRY_CODE is null
if [ $? != 0 ]
then
  echo "All of the country codes were matched with ISO_CODE3 values" >> $TLM_LOG_FILE
else
  echo "One or more country code have been set to null because not matching" >> $TLM_LOG_FILE
  echo "with existing ones" >> $TLM_LOG_FILE
  echo "One or more country code have been set to null because not matching"
  echo "with existing ones"
fi

# Creating contraints, foreing keys, triggers views
echo "Creating contraints, foreing keys, triggers views" >> $TLM_LOG_FILE
echo "-- running..."
echo "Foreing keys and triggers for SWCAT schema" >> $TLM_LOG_FILE
db2 -f swcat_create_fct.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred creating foreign keys or triggers or views" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo SWCAT foreign keys and triggers created successfully >> $TLM_LOG_FILE

echo "Contraints and triggers for SWCAT schema" >> $TLM_LOG_FILE
db2 -f swcat_create_tr.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred creating foreign keys or triggers or views" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "SWCAT contraints and triggers created successfully" >> $TLM_LOG_FILE

echo "Foreing keys and triggers for ADM schema" >> $TLM_LOG_FILE
db2 -f create_fct.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred creating foreign keys or triggers or views" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "ADM foreign keys and triggers created successfully" >> $TLM_LOG_FILE

echo "Contraints and triggers for ADM schema" >> $TLM_LOG_FILE
db2 -f create_tr.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred creating foreign keys or triggers or views" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "ADM contraints and triggers created successfully" >> $TLM_LOG_FILE

echo "Views for ADM schema" >> $TLM_LOG_FILE
db2 -f create_v.sql +o -t -z $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred creating foreign keys or triggers or views" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "ADM views created successfully" >> $TLM_LOG_FILE

# Catalog management - after triggers/contraints creation
echo "Building hierarchy over custom entries" >> $TLM_LOG_FILE
echo "-- running..."
$JAVA_BIN -cp $JAVA_CLASSPATH CatalogHandler >> $TLM_LOG_FILE
if [ $? != 0 ]
then
  echo "A failure occurred managing catalog hierarchy" >> $TLM_LOG_FILE
  echo "Migration procedure failed - see log ($TLM_LOG_FILE) for details"
  echo "Dropping corrupted db" >> $TLM_LOG_FILE
  db2 -t +o drop db TLMA >> $TLM_LOG_FILE
  echo "Creating database to be restored" >> $TLM_LOG_FILE
  db2 -f create_db.sql +o -t -z $TLM_LOG_FILE
  echo "Restoring db" >> $TLM_LOG_FILE
  db2 restore db TLMA replace existing >> $TLM_LOG_FILE
  if test -f usage_comp_111_21.dat
  then
    rm -f usage_comp_111_21.dat
  fi
  if test -f usage_comp_user_111_21.dat
  then
    rm -f usage_comp_user_111_21.dat
  fi
  if test -f usage_lic_111_21.dat
  then
    rm -f usage_lic_111_21.dat
  fi
  db2 +o disconnect TLMA
  return
fi
echo "Hierarchy over custom entries building completed successfully" >> $TLM_LOG_FILE

#disconnect and clean
if test -f usage_comp_111_21.dat
then
  rm -f usage_comp_111_21.dat
fi
if test -f usage_comp_user_111_21.dat
then
  rm -f usage_comp_user_111_21.dat
fi
if test -f usage_lic_111_21.dat
then
  rm -f usage_lic_111_21.dat
fi
db2 +o disconnect TLMA

echo "Administration database has been successfully migrated to 2.1."
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
echo "Administration database has been successfully migrated to 2.1." >> $TLM_LOG_FILE
date >> $TLM_LOG_FILE
echo "_______________________________________________________________________________" >> $TLM_LOG_FILE
