-- ****************************************************************************
-- * Licensed Materials - Property of IBM
-- * 5724-D33
-- * IBM Tivoli License Manager
-- *
-- * (C) Copyright IBM Corp. 2002, 2004.  All Rights Reserved.
-- *              
-- * US Government Users Restricted Rights - Use, duplication or
-- * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-- ****************************************************************************


-------------------------------------------------------------------------------
-- Create foreign keys
-------------------------------------------------------------------------------

alter table SWCAT.COMP_MOD_REL add constraint CMR_CMP_FK
    foreign key(COMPONENT_ID) references SWCAT.COMPONENT on delete cascade;

alter table SWCAT.COMP_MOD_REL add constraint CMR_MOD_FK
    foreign key(MODULE_ID) references SWCAT.MODULE on delete cascade;

alter table SWCAT.COMPONENT add constraint CMP_VEN_FK
    foreign key(VENDOR_ID) references SWCAT.VENDOR on delete cascade;

alter table SWCAT.COMPONENT add constraint CMP_CMP_FK
    foreign key(COMPONENT_ID) references SWCAT.COMPONENT on delete cascade;


-------------------------------------------------------------------------------
-- Create check constraints
-------------------------------------------------------------------------------

alter table SWCAT.COMPONENT add constraint COMPONENT_CK1
    check  ( OS_NAME in  ( 'Unix', 'Windows', 'OS/400', 'JVM') );

alter table SWCAT.COMPONENT add constraint COMPONENT_CK2
    check  ( TREE_LEVEL in  ( 1, 2, 3) );

alter table SWCAT.COMPONENT add constraint COMPONENT_CK3
    check  ( LEVEL_ in  ( 1, 2, 3, 4, 10) );

alter table SWCAT.COMPONENT add constraint COMPONENT_CK4
    check  ( IS_IBM in  ( 0, 1) );

alter table SWCAT.MODULE add constraint MODULE_CK1
    check  ( OS_NAME in  ( 'Unix', 'Windows', 'OS/400', 'JVM') );

alter table SWCAT.MODULE add constraint MODULE_CK2
    check  ( TYPE in  ( 0, 10, 100, 101, 102, 103, 104, 150, 151, 152, 200, 300) );

alter table SWCAT.MODULE add constraint MODULE_CK3
    check  ( SCOPE in  ( 0, 1, 2) );

alter table SWCAT.MODULE add constraint MODULE_CK4
    check  ( ENABLED in  ( 0, 1) );

alter table SWCAT.UNKNOWN add constraint UNKNOWN_CK1
    check  ( OS_NAME in  ( 'Unix', 'Windows', 'OS/400', 'JVM') );

alter table SWCAT.UNKNOWN add constraint UNKNOWN_CK2
    check  ( TYPE in  ( 0, 10, 200, 300) );

alter table SWCAT.UNKNOWN add constraint UNKNOWN_CK3
    check  ( ENABLED in  ( 0, 1) );


-------------------------------------------------------------------------------
-- Create timestamp triggers
-------------------------------------------------------------------------------

create trigger SWCAT.COMP_MOD_REL_TR1
    no cascade before insert on SWCAT.COMP_MOD_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger SWCAT.COMP_MOD_REL_TR2
    no cascade before update on SWCAT.COMP_MOD_REL
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger SWCAT.COMPONENT_TR1
    no cascade before insert on SWCAT.COMPONENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger SWCAT.COMPONENT_TR2
    no cascade before update on SWCAT.COMPONENT
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger SWCAT.MODULE_TR1
    no cascade before insert on SWCAT.MODULE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger SWCAT.MODULE_TR2
    no cascade before update on SWCAT.MODULE
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger SWCAT.UNKNOWN_TR1
    no cascade before insert on SWCAT.UNKNOWN
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger SWCAT.UNKNOWN_TR2
    no cascade before update on SWCAT.UNKNOWN
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------

create trigger SWCAT.VENDOR_TR1
    no cascade before insert on SWCAT.VENDOR
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

create trigger SWCAT.VENDOR_TR2
    no cascade before update on SWCAT.VENDOR
    referencing new as NEW for each row mode db2sql
    set NEW.LAST_MODIFIED = current timestamp - current timezone;

-------------------------------------------------------------------------------
